/*  
 *  Copyright (c) 2003 Dan Gudmundsson
 *  See the file "license.terms" for information on usage and redistribution
 *  of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 *     $Id: esdl_glext_fp.h,v 1.2 2004/03/31 14:00:15 dgud Exp $
 *
 */
{ glBlendColorFunc,  "glBlendColor", egl_blendColor, &esdl_glBlendColor},
{ glBlendEquationFunc,  "glBlendEquation", egl_blendEquation, &esdl_glBlendEquation},
{ glDrawRangeElementsFunc,  "glDrawRangeElements", egl_drawRangeElements, &esdl_glDrawRangeElements},
{ glColorTableFunc,  "glColorTable", egl_colorTable, &esdl_glColorTable},
{ glColorTableParameterfvFunc,  "glColorTableParameterfv", egl_colorTableParameterfv, &esdl_glColorTableParameterfv},
{ glColorTableParameterivFunc,  "glColorTableParameteriv", egl_colorTableParameteriv, &esdl_glColorTableParameteriv},
{ glCopyColorTableFunc,  "glCopyColorTable", egl_copyColorTable, &esdl_glCopyColorTable},
{ glGetColorTableFunc,  "glGetColorTable", egl_getColorTable, &esdl_glGetColorTable},
{ glGetColorTableParameterfvFunc,  "glGetColorTableParameterfv", egl_getColorTableParameterfv, &esdl_glGetColorTableParameterfv},
{ glGetColorTableParameterivFunc,  "glGetColorTableParameteriv", egl_getColorTableParameteriv, &esdl_glGetColorTableParameteriv},
{ glColorSubTableFunc,  "glColorSubTable", egl_colorSubTable, &esdl_glColorSubTable},
{ glCopyColorSubTableFunc,  "glCopyColorSubTable", egl_copyColorSubTable, &esdl_glCopyColorSubTable},
{ glConvolutionFilter1DFunc,  "glConvolutionFilter1D", egl_convolutionFilter1D, &esdl_glConvolutionFilter1D},
{ glConvolutionFilter2DFunc,  "glConvolutionFilter2D", egl_convolutionFilter2D, &esdl_glConvolutionFilter2D},
{ glConvolutionParameterfFunc,  "glConvolutionParameterf", egl_convolutionParameterf, &esdl_glConvolutionParameterf},
{ glConvolutionParameterfvFunc,  "glConvolutionParameterfv", egl_convolutionParameterfv, &esdl_glConvolutionParameterfv},
{ glConvolutionParameteriFunc,  "glConvolutionParameteri", egl_convolutionParameteri, &esdl_glConvolutionParameteri},
{ glConvolutionParameterivFunc,  "glConvolutionParameteriv", egl_convolutionParameteriv, &esdl_glConvolutionParameteriv},
{ glCopyConvolutionFilter1DFunc,  "glCopyConvolutionFilter1D", egl_copyConvolutionFilter1D, &esdl_glCopyConvolutionFilter1D},
{ glCopyConvolutionFilter2DFunc,  "glCopyConvolutionFilter2D", egl_copyConvolutionFilter2D, &esdl_glCopyConvolutionFilter2D},
{ glGetConvolutionFilterFunc,  "glGetConvolutionFilter", egl_getConvolutionFilter, &esdl_glGetConvolutionFilter},
{ glGetConvolutionParameterfvFunc,  "glGetConvolutionParameterfv", egl_getConvolutionParameterfv, &esdl_glGetConvolutionParameterfv},
{ glGetConvolutionParameterivFunc,  "glGetConvolutionParameteriv", egl_getConvolutionParameteriv, &esdl_glGetConvolutionParameteriv},
{ glGetSeparableFilterFunc,  "glGetSeparableFilter", egl_getSeparableFilter, &esdl_glGetSeparableFilter},
{ glSeparableFilter2DFunc,  "glSeparableFilter2D", egl_separableFilter2D, &esdl_glSeparableFilter2D},
{ glGetHistogramFunc,  "glGetHistogram", egl_getHistogram, &esdl_glGetHistogram},
{ glGetHistogramParameterfvFunc,  "glGetHistogramParameterfv", egl_getHistogramParameterfv, &esdl_glGetHistogramParameterfv},
{ glGetHistogramParameterivFunc,  "glGetHistogramParameteriv", egl_getHistogramParameteriv, &esdl_glGetHistogramParameteriv},
{ glGetMinmaxFunc,  "glGetMinmax", egl_getMinmax, &esdl_glGetMinmax},
{ glGetMinmaxParameterfvFunc,  "glGetMinmaxParameterfv", egl_getMinmaxParameterfv, &esdl_glGetMinmaxParameterfv},
{ glGetMinmaxParameterivFunc,  "glGetMinmaxParameteriv", egl_getMinmaxParameteriv, &esdl_glGetMinmaxParameteriv},
{ glHistogramFunc,  "glHistogram", egl_histogram, &esdl_glHistogram},
{ glMinmaxFunc,  "glMinmax", egl_minmax, &esdl_glMinmax},
{ glResetHistogramFunc,  "glResetHistogram", egl_resetHistogram, &esdl_glResetHistogram},
{ glResetMinmaxFunc,  "glResetMinmax", egl_resetMinmax, &esdl_glResetMinmax},
{ glTexImage3DFunc,  "glTexImage3D", egl_texImage3D, &esdl_glTexImage3D},
{ glTexSubImage3DFunc,  "glTexSubImage3D", egl_texSubImage3D, &esdl_glTexSubImage3D},
{ glCopyTexSubImage3DFunc,  "glCopyTexSubImage3D", egl_copyTexSubImage3D, &esdl_glCopyTexSubImage3D},
{ glActiveTextureFunc,  "glActiveTexture", egl_activeTexture, &esdl_glActiveTexture},
{ glClientActiveTextureFunc,  "glClientActiveTexture", egl_clientActiveTexture, &esdl_glClientActiveTexture},
{ glMultiTexCoord1dvFunc,  "glMultiTexCoord1dv", egl_multiTexCoord1dv, &esdl_glMultiTexCoord1dv},
{ glMultiTexCoord1fvFunc,  "glMultiTexCoord1fv", egl_multiTexCoord1fv, &esdl_glMultiTexCoord1fv},
{ glMultiTexCoord1ivFunc,  "glMultiTexCoord1iv", egl_multiTexCoord1iv, &esdl_glMultiTexCoord1iv},
{ glMultiTexCoord1svFunc,  "glMultiTexCoord1sv", egl_multiTexCoord1sv, &esdl_glMultiTexCoord1sv},
{ glMultiTexCoord2dvFunc,  "glMultiTexCoord2dv", egl_multiTexCoord2dv, &esdl_glMultiTexCoord2dv},
{ glMultiTexCoord2fvFunc,  "glMultiTexCoord2fv", egl_multiTexCoord2fv, &esdl_glMultiTexCoord2fv},
{ glMultiTexCoord2ivFunc,  "glMultiTexCoord2iv", egl_multiTexCoord2iv, &esdl_glMultiTexCoord2iv},
{ glMultiTexCoord2svFunc,  "glMultiTexCoord2sv", egl_multiTexCoord2sv, &esdl_glMultiTexCoord2sv},
{ glMultiTexCoord3dvFunc,  "glMultiTexCoord3dv", egl_multiTexCoord3dv, &esdl_glMultiTexCoord3dv},
{ glMultiTexCoord3fvFunc,  "glMultiTexCoord3fv", egl_multiTexCoord3fv, &esdl_glMultiTexCoord3fv},
{ glMultiTexCoord3ivFunc,  "glMultiTexCoord3iv", egl_multiTexCoord3iv, &esdl_glMultiTexCoord3iv},
{ glMultiTexCoord3svFunc,  "glMultiTexCoord3sv", egl_multiTexCoord3sv, &esdl_glMultiTexCoord3sv},
{ glMultiTexCoord4dvFunc,  "glMultiTexCoord4dv", egl_multiTexCoord4dv, &esdl_glMultiTexCoord4dv},
{ glMultiTexCoord4fvFunc,  "glMultiTexCoord4fv", egl_multiTexCoord4fv, &esdl_glMultiTexCoord4fv},
{ glMultiTexCoord4ivFunc,  "glMultiTexCoord4iv", egl_multiTexCoord4iv, &esdl_glMultiTexCoord4iv},
{ glMultiTexCoord4svFunc,  "glMultiTexCoord4sv", egl_multiTexCoord4sv, &esdl_glMultiTexCoord4sv},
{ glLoadTransposeMatrixfFunc,  "glLoadTransposeMatrixf", egl_loadTransposeMatrixf, &esdl_glLoadTransposeMatrixf},
{ glLoadTransposeMatrixdFunc,  "glLoadTransposeMatrixd", egl_loadTransposeMatrixd, &esdl_glLoadTransposeMatrixd},
{ glMultTransposeMatrixfFunc,  "glMultTransposeMatrixf", egl_multTransposeMatrixf, &esdl_glMultTransposeMatrixf},
{ glMultTransposeMatrixdFunc,  "glMultTransposeMatrixd", egl_multTransposeMatrixd, &esdl_glMultTransposeMatrixd},
{ glSampleCoverageFunc,  "glSampleCoverage", egl_sampleCoverage, &esdl_glSampleCoverage},
{ glCompressedTexImage3DFunc,  "glCompressedTexImage3D", egl_compressedTexImage3D, &esdl_glCompressedTexImage3D},
{ glCompressedTexImage2DFunc,  "glCompressedTexImage2D", egl_compressedTexImage2D, &esdl_glCompressedTexImage2D},
{ glCompressedTexImage1DFunc,  "glCompressedTexImage1D", egl_compressedTexImage1D, &esdl_glCompressedTexImage1D},
{ glCompressedTexSubImage3DFunc,  "glCompressedTexSubImage3D", egl_compressedTexSubImage3D, &esdl_glCompressedTexSubImage3D},
{ glCompressedTexSubImage2DFunc,  "glCompressedTexSubImage2D", egl_compressedTexSubImage2D, &esdl_glCompressedTexSubImage2D},
{ glCompressedTexSubImage1DFunc,  "glCompressedTexSubImage1D", egl_compressedTexSubImage1D, &esdl_glCompressedTexSubImage1D},
{ glGetCompressedTexImageFunc,  "glGetCompressedTexImage", egl_getCompressedTexImage, &esdl_glGetCompressedTexImage},
{ glBlendFuncSeparateFunc,  "glBlendFuncSeparate", egl_blendFuncSeparate, &esdl_glBlendFuncSeparate},
{ glFogCoordfFunc,  "glFogCoordf", egl_fogCoordf, &esdl_glFogCoordf},
{ glFogCoordfvFunc,  "glFogCoordfv", egl_fogCoordfv, &esdl_glFogCoordfv},
{ glFogCoorddFunc,  "glFogCoordd", egl_fogCoordd, &esdl_glFogCoordd},
{ glFogCoorddvFunc,  "glFogCoorddv", egl_fogCoorddv, &esdl_glFogCoorddv},
{ glFogCoordPointerFunc,  "glFogCoordPointer", egl_fogCoordPointer, &esdl_glFogCoordPointer},
{ glMultiDrawArraysFunc,  "glMultiDrawArrays", egl_multiDrawArrays, &esdl_glMultiDrawArrays},
{ glPointParameterfFunc,  "glPointParameterf", egl_pointParameterf, &esdl_glPointParameterf},
{ glPointParameterfvFunc,  "glPointParameterfv", egl_pointParameterfv, &esdl_glPointParameterfv},
{ glPointParameteriFunc,  "glPointParameteri", egl_pointParameteri, &esdl_glPointParameteri},
{ glPointParameterivFunc,  "glPointParameteriv", egl_pointParameteriv, &esdl_glPointParameteriv},
{ glSecondaryColor3bvFunc,  "glSecondaryColor3bv", egl_secondaryColor3bv, &esdl_glSecondaryColor3bv},
{ glSecondaryColor3dvFunc,  "glSecondaryColor3dv", egl_secondaryColor3dv, &esdl_glSecondaryColor3dv},
{ glSecondaryColor3fvFunc,  "glSecondaryColor3fv", egl_secondaryColor3fv, &esdl_glSecondaryColor3fv},
{ glSecondaryColor3ivFunc,  "glSecondaryColor3iv", egl_secondaryColor3iv, &esdl_glSecondaryColor3iv},
{ glSecondaryColor3svFunc,  "glSecondaryColor3sv", egl_secondaryColor3sv, &esdl_glSecondaryColor3sv},
{ glSecondaryColor3ubvFunc,  "glSecondaryColor3ubv", egl_secondaryColor3ubv, &esdl_glSecondaryColor3ubv},
{ glSecondaryColor3uivFunc,  "glSecondaryColor3uiv", egl_secondaryColor3uiv, &esdl_glSecondaryColor3uiv},
{ glSecondaryColor3usvFunc,  "glSecondaryColor3usv", egl_secondaryColor3usv, &esdl_glSecondaryColor3usv},
{ glSecondaryColorPointerFunc,  "glSecondaryColorPointer", egl_secondaryColorPointer, &esdl_glSecondaryColorPointer},
{ glWindowPos2dvFunc,  "glWindowPos2dv", egl_windowPos2dv, &esdl_glWindowPos2dv},
{ glWindowPos2fvFunc,  "glWindowPos2fv", egl_windowPos2fv, &esdl_glWindowPos2fv},
{ glWindowPos2ivFunc,  "glWindowPos2iv", egl_windowPos2iv, &esdl_glWindowPos2iv},
{ glWindowPos2svFunc,  "glWindowPos2sv", egl_windowPos2sv, &esdl_glWindowPos2sv},
{ glWindowPos3dvFunc,  "glWindowPos3dv", egl_windowPos3dv, &esdl_glWindowPos3dv},
{ glWindowPos3fvFunc,  "glWindowPos3fv", egl_windowPos3fv, &esdl_glWindowPos3fv},
{ glWindowPos3ivFunc,  "glWindowPos3iv", egl_windowPos3iv, &esdl_glWindowPos3iv},
{ glWindowPos3svFunc,  "glWindowPos3sv", egl_windowPos3sv, &esdl_glWindowPos3sv},
{ glGenQueriesFunc,  "glGenQueries", egl_genQueries, &esdl_glGenQueries},
{ glDeleteQueriesFunc,  "glDeleteQueries", egl_deleteQueries, &esdl_glDeleteQueries},
{ glIsQueryFunc,  "glIsQuery", egl_isQuery, &esdl_glIsQuery},
{ glBeginQueryFunc,  "glBeginQuery", egl_beginQuery, &esdl_glBeginQuery},
{ glEndQueryFunc,  "glEndQuery", egl_endQuery, &esdl_glEndQuery},
{ glGetQueryivFunc,  "glGetQueryiv", egl_getQueryiv, &esdl_glGetQueryiv},
{ glGetQueryObjectivFunc,  "glGetQueryObjectiv", egl_getQueryObjectiv, &esdl_glGetQueryObjectiv},
{ glGetQueryObjectuivFunc,  "glGetQueryObjectuiv", egl_getQueryObjectuiv, &esdl_glGetQueryObjectuiv},
{ glBindBufferFunc,  "glBindBuffer", egl_bindBuffer, &esdl_glBindBuffer},
{ glDeleteBuffersFunc,  "glDeleteBuffers", egl_deleteBuffers, &esdl_glDeleteBuffers},
{ glGenBuffersFunc,  "glGenBuffers", egl_genBuffers, &esdl_glGenBuffers},
{ glIsBufferFunc,  "glIsBuffer", egl_isBuffer, &esdl_glIsBuffer},
{ glBufferDataFunc,  "glBufferData", egl_bufferData, &esdl_glBufferData},
{ glBufferSubDataFunc,  "glBufferSubData", egl_bufferSubData, &esdl_glBufferSubData},
{ glGetBufferSubDataFunc,  "glGetBufferSubData", egl_getBufferSubData, &esdl_glGetBufferSubData},
{ glUnmapBufferFunc,  "glUnmapBuffer", egl_unmapBuffer, &esdl_glUnmapBuffer},
{ glGetBufferParameterivFunc,  "glGetBufferParameteriv", egl_getBufferParameteriv, &esdl_glGetBufferParameteriv},
{ glGetBufferPointervFunc,  "glGetBufferPointerv", egl_getBufferPointerv, &esdl_glGetBufferPointerv},
{ glWeightbvARBFunc,  "glWeightbvARB", egl_weightbvARB, &esdl_glWeightbvARB},
{ glWeightsvARBFunc,  "glWeightsvARB", egl_weightsvARB, &esdl_glWeightsvARB},
{ glWeightivARBFunc,  "glWeightivARB", egl_weightivARB, &esdl_glWeightivARB},
{ glWeightfvARBFunc,  "glWeightfvARB", egl_weightfvARB, &esdl_glWeightfvARB},
{ glWeightdvARBFunc,  "glWeightdvARB", egl_weightdvARB, &esdl_glWeightdvARB},
{ glWeightubvARBFunc,  "glWeightubvARB", egl_weightubvARB, &esdl_glWeightubvARB},
{ glWeightusvARBFunc,  "glWeightusvARB", egl_weightusvARB, &esdl_glWeightusvARB},
{ glWeightuivARBFunc,  "glWeightuivARB", egl_weightuivARB, &esdl_glWeightuivARB},
{ glWeightPointerARBFunc,  "glWeightPointerARB", egl_weightPointerARB, &esdl_glWeightPointerARB},
{ glVertexBlendARBFunc,  "glVertexBlendARB", egl_vertexBlendARB, &esdl_glVertexBlendARB},
{ glCurrentPaletteMatrixARBFunc,  "glCurrentPaletteMatrixARB", egl_currentPaletteMatrixARB, &esdl_glCurrentPaletteMatrixARB},
{ glMatrixIndexubvARBFunc,  "glMatrixIndexubvARB", egl_matrixIndexubvARB, &esdl_glMatrixIndexubvARB},
{ glMatrixIndexusvARBFunc,  "glMatrixIndexusvARB", egl_matrixIndexusvARB, &esdl_glMatrixIndexusvARB},
{ glMatrixIndexuivARBFunc,  "glMatrixIndexuivARB", egl_matrixIndexuivARB, &esdl_glMatrixIndexuivARB},
{ glMatrixIndexPointerARBFunc,  "glMatrixIndexPointerARB", egl_matrixIndexPointerARB, &esdl_glMatrixIndexPointerARB},
{ glVertexAttrib1dvARBFunc,  "glVertexAttrib1dvARB", egl_vertexAttrib1dvARB, &esdl_glVertexAttrib1dvARB},
{ glVertexAttrib1fvARBFunc,  "glVertexAttrib1fvARB", egl_vertexAttrib1fvARB, &esdl_glVertexAttrib1fvARB},
{ glVertexAttrib1svARBFunc,  "glVertexAttrib1svARB", egl_vertexAttrib1svARB, &esdl_glVertexAttrib1svARB},
{ glVertexAttrib2dvARBFunc,  "glVertexAttrib2dvARB", egl_vertexAttrib2dvARB, &esdl_glVertexAttrib2dvARB},
{ glVertexAttrib2fvARBFunc,  "glVertexAttrib2fvARB", egl_vertexAttrib2fvARB, &esdl_glVertexAttrib2fvARB},
{ glVertexAttrib2svARBFunc,  "glVertexAttrib2svARB", egl_vertexAttrib2svARB, &esdl_glVertexAttrib2svARB},
{ glVertexAttrib3dvARBFunc,  "glVertexAttrib3dvARB", egl_vertexAttrib3dvARB, &esdl_glVertexAttrib3dvARB},
{ glVertexAttrib3fvARBFunc,  "glVertexAttrib3fvARB", egl_vertexAttrib3fvARB, &esdl_glVertexAttrib3fvARB},
{ glVertexAttrib3svARBFunc,  "glVertexAttrib3svARB", egl_vertexAttrib3svARB, &esdl_glVertexAttrib3svARB},
{ glVertexAttrib4NbvARBFunc,  "glVertexAttrib4NbvARB", egl_vertexAttrib4NbvARB, &esdl_glVertexAttrib4NbvARB},
{ glVertexAttrib4NivARBFunc,  "glVertexAttrib4NivARB", egl_vertexAttrib4NivARB, &esdl_glVertexAttrib4NivARB},
{ glVertexAttrib4NsvARBFunc,  "glVertexAttrib4NsvARB", egl_vertexAttrib4NsvARB, &esdl_glVertexAttrib4NsvARB},
{ glVertexAttrib4NubARBFunc,  "glVertexAttrib4NubARB", egl_vertexAttrib4NubARB, &esdl_glVertexAttrib4NubARB},
{ glVertexAttrib4NubvARBFunc,  "glVertexAttrib4NubvARB", egl_vertexAttrib4NubvARB, &esdl_glVertexAttrib4NubvARB},
{ glVertexAttrib4NuivARBFunc,  "glVertexAttrib4NuivARB", egl_vertexAttrib4NuivARB, &esdl_glVertexAttrib4NuivARB},
{ glVertexAttrib4NusvARBFunc,  "glVertexAttrib4NusvARB", egl_vertexAttrib4NusvARB, &esdl_glVertexAttrib4NusvARB},
{ glVertexAttrib4bvARBFunc,  "glVertexAttrib4bvARB", egl_vertexAttrib4bvARB, &esdl_glVertexAttrib4bvARB},
{ glVertexAttrib4dvARBFunc,  "glVertexAttrib4dvARB", egl_vertexAttrib4dvARB, &esdl_glVertexAttrib4dvARB},
{ glVertexAttrib4fvARBFunc,  "glVertexAttrib4fvARB", egl_vertexAttrib4fvARB, &esdl_glVertexAttrib4fvARB},
{ glVertexAttrib4ivARBFunc,  "glVertexAttrib4ivARB", egl_vertexAttrib4ivARB, &esdl_glVertexAttrib4ivARB},
{ glVertexAttrib4svARBFunc,  "glVertexAttrib4svARB", egl_vertexAttrib4svARB, &esdl_glVertexAttrib4svARB},
{ glVertexAttrib4ubvARBFunc,  "glVertexAttrib4ubvARB", egl_vertexAttrib4ubvARB, &esdl_glVertexAttrib4ubvARB},
{ glVertexAttrib4uivARBFunc,  "glVertexAttrib4uivARB", egl_vertexAttrib4uivARB, &esdl_glVertexAttrib4uivARB},
{ glVertexAttrib4usvARBFunc,  "glVertexAttrib4usvARB", egl_vertexAttrib4usvARB, &esdl_glVertexAttrib4usvARB},
{ glVertexAttribPointerARBFunc,  "glVertexAttribPointerARB", egl_vertexAttribPointerARB, &esdl_glVertexAttribPointerARB},
{ glEnableVertexAttribArrayARBFunc,  "glEnableVertexAttribArrayARB", egl_enableVertexAttribArrayARB, &esdl_glEnableVertexAttribArrayARB},
{ glDisableVertexAttribArrayARBFunc,  "glDisableVertexAttribArrayARB", egl_disableVertexAttribArrayARB, &esdl_glDisableVertexAttribArrayARB},
{ glProgramStringARBFunc,  "glProgramStringARB", egl_programStringARB, &esdl_glProgramStringARB},
{ glBindProgramARBFunc,  "glBindProgramARB", egl_bindProgramARB, &esdl_glBindProgramARB},
{ glDeleteProgramsARBFunc,  "glDeleteProgramsARB", egl_deleteProgramsARB, &esdl_glDeleteProgramsARB},
{ glGenProgramsARBFunc,  "glGenProgramsARB", egl_genProgramsARB, &esdl_glGenProgramsARB},
{ glProgramEnvParameter4dvARBFunc,  "glProgramEnvParameter4dvARB", egl_programEnvParameter4dvARB, &esdl_glProgramEnvParameter4dvARB},
{ glProgramEnvParameter4fvARBFunc,  "glProgramEnvParameter4fvARB", egl_programEnvParameter4fvARB, &esdl_glProgramEnvParameter4fvARB},
{ glProgramLocalParameter4dvARBFunc,  "glProgramLocalParameter4dvARB", egl_programLocalParameter4dvARB, &esdl_glProgramLocalParameter4dvARB},
{ glProgramLocalParameter4fvARBFunc,  "glProgramLocalParameter4fvARB", egl_programLocalParameter4fvARB, &esdl_glProgramLocalParameter4fvARB},
{ glGetProgramEnvParameterdvARBFunc,  "glGetProgramEnvParameterdvARB", egl_getProgramEnvParameterdvARB, &esdl_glGetProgramEnvParameterdvARB},
{ glGetProgramEnvParameterfvARBFunc,  "glGetProgramEnvParameterfvARB", egl_getProgramEnvParameterfvARB, &esdl_glGetProgramEnvParameterfvARB},
{ glGetProgramLocalParameterdvARBFunc,  "glGetProgramLocalParameterdvARB", egl_getProgramLocalParameterdvARB, &esdl_glGetProgramLocalParameterdvARB},
{ glGetProgramLocalParameterfvARBFunc,  "glGetProgramLocalParameterfvARB", egl_getProgramLocalParameterfvARB, &esdl_glGetProgramLocalParameterfvARB},
{ glGetProgramivARBFunc,  "glGetProgramivARB", egl_getProgramivARB, &esdl_glGetProgramivARB},
{ glGetProgramStringARBFunc,  "glGetProgramStringARB", egl_getProgramStringARB, &esdl_glGetProgramStringARB},
{ glGetVertexAttribdvARBFunc,  "glGetVertexAttribdvARB", egl_getVertexAttribdvARB, &esdl_glGetVertexAttribdvARB},
{ glGetVertexAttribfvARBFunc,  "glGetVertexAttribfvARB", egl_getVertexAttribfvARB, &esdl_glGetVertexAttribfvARB},
{ glGetVertexAttribivARBFunc,  "glGetVertexAttribivARB", egl_getVertexAttribivARB, &esdl_glGetVertexAttribivARB},
{ glGetVertexAttribPointervARBFunc,  "glGetVertexAttribPointervARB", egl_getVertexAttribPointervARB, &esdl_glGetVertexAttribPointervARB},
{ glIsProgramARBFunc,  "glIsProgramARB", egl_isProgramARB, &esdl_glIsProgramARB},
{ glDeleteObjectARBFunc,  "glDeleteObjectARB", egl_deleteObjectARB, &esdl_glDeleteObjectARB},
{ glGetHandleARBFunc,  "glGetHandleARB", egl_getHandleARB, &esdl_glGetHandleARB},
{ glDetachObjectARBFunc,  "glDetachObjectARB", egl_detachObjectARB, &esdl_glDetachObjectARB},
{ glCreateShaderObjectARBFunc,  "glCreateShaderObjectARB", egl_createShaderObjectARB, &esdl_glCreateShaderObjectARB},
{ glShaderSourceARBFunc,  "glShaderSourceARB", egl_shaderSourceARB, &esdl_glShaderSourceARB},
{ glCompileShaderARBFunc,  "glCompileShaderARB", egl_compileShaderARB, &esdl_glCompileShaderARB},
{ glCreateProgramObjectARBFunc,  "glCreateProgramObjectARB", egl_createProgramObjectARB, &esdl_glCreateProgramObjectARB},
{ glAttachObjectARBFunc,  "glAttachObjectARB", egl_attachObjectARB, &esdl_glAttachObjectARB},
{ glLinkProgramARBFunc,  "glLinkProgramARB", egl_linkProgramARB, &esdl_glLinkProgramARB},
{ glUseProgramObjectARBFunc,  "glUseProgramObjectARB", egl_useProgramObjectARB, &esdl_glUseProgramObjectARB},
{ glValidateProgramARBFunc,  "glValidateProgramARB", egl_validateProgramARB, &esdl_glValidateProgramARB},
{ glUniform1fvARBFunc,  "glUniform1fvARB", egl_uniform1fvARB, &esdl_glUniform1fvARB},
{ glUniform2fvARBFunc,  "glUniform2fvARB", egl_uniform2fvARB, &esdl_glUniform2fvARB},
{ glUniform3fvARBFunc,  "glUniform3fvARB", egl_uniform3fvARB, &esdl_glUniform3fvARB},
{ glUniform4fvARBFunc,  "glUniform4fvARB", egl_uniform4fvARB, &esdl_glUniform4fvARB},
{ glUniform1ivARBFunc,  "glUniform1ivARB", egl_uniform1ivARB, &esdl_glUniform1ivARB},
{ glUniform2ivARBFunc,  "glUniform2ivARB", egl_uniform2ivARB, &esdl_glUniform2ivARB},
{ glUniform3ivARBFunc,  "glUniform3ivARB", egl_uniform3ivARB, &esdl_glUniform3ivARB},
{ glUniform4ivARBFunc,  "glUniform4ivARB", egl_uniform4ivARB, &esdl_glUniform4ivARB},
{ glUniformMatrix2fvARBFunc,  "glUniformMatrix2fvARB", egl_uniformMatrix2fvARB, &esdl_glUniformMatrix2fvARB},
{ glUniformMatrix3fvARBFunc,  "glUniformMatrix3fvARB", egl_uniformMatrix3fvARB, &esdl_glUniformMatrix3fvARB},
{ glUniformMatrix4fvARBFunc,  "glUniformMatrix4fvARB", egl_uniformMatrix4fvARB, &esdl_glUniformMatrix4fvARB},
{ glGetObjectParameterfvARBFunc,  "glGetObjectParameterfvARB", egl_getObjectParameterfvARB, &esdl_glGetObjectParameterfvARB},
{ glGetObjectParameterivARBFunc,  "glGetObjectParameterivARB", egl_getObjectParameterivARB, &esdl_glGetObjectParameterivARB},
{ glGetInfoLogARBFunc,  "glGetInfoLogARB", egl_getInfoLogARB, &esdl_glGetInfoLogARB},
{ glGetAttachedObjectsARBFunc,  "glGetAttachedObjectsARB", egl_getAttachedObjectsARB, &esdl_glGetAttachedObjectsARB},
{ glGetUniformLocationARBFunc,  "glGetUniformLocationARB", egl_getUniformLocationARB, &esdl_glGetUniformLocationARB},
{ glGetActiveUniformARBFunc,  "glGetActiveUniformARB", egl_getActiveUniformARB, &esdl_glGetActiveUniformARB},
{ glGetUniformfvARBFunc,  "glGetUniformfvARB", egl_getUniformfvARB, &esdl_glGetUniformfvARB},
{ glGetUniformivARBFunc,  "glGetUniformivARB", egl_getUniformivARB, &esdl_glGetUniformivARB},
{ glGetShaderSourceARBFunc,  "glGetShaderSourceARB", egl_getShaderSourceARB, &esdl_glGetShaderSourceARB},
{ glBindAttribLocationARBFunc,  "glBindAttribLocationARB", egl_bindAttribLocationARB, &esdl_glBindAttribLocationARB},
{ glGetActiveAttribARBFunc,  "glGetActiveAttribARB", egl_getActiveAttribARB, &esdl_glGetActiveAttribARB},
{ glGetAttribLocationARBFunc,  "glGetAttribLocationARB", egl_getAttribLocationARB, &esdl_glGetAttribLocationARB},
{ glStencilOpSeparateATIFunc,  "glStencilOpSeparateATI", egl_stencilOpSeparateATI, &esdl_glStencilOpSeparateATI},
{ glStencilFuncSeparateATIFunc,  "glStencilFuncSeparateATI", egl_stencilFuncSeparateATI, &esdl_glStencilFuncSeparateATI},
